California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 57 - ABX5 9 (CHAPTER 2, STATUTES 2003, 5TH EXTRAORDINARY SESSION). OROPEZA. ECONOMIC RECOVERY BONDS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1260631 | NO ON 57/CALIFORNIANS AGAINST MORTGAGING OUR CHILDREN'S FUTURE: SUPPORTED BY STATE TREASURER PHIL ANGELIDES AND STEVE BING | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261936 | CALIFORNIANS FOR A BALANCED BUDGET - YES ON 57 & 58 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1263036 | DEMOCRATS FOR 57/58 | SUPPORT